==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/container_cluster/ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig.java <==
package com.hashicorp.cdktf.providers.google.container_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:40.252Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.containerCluster.ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig")
@software.amazon.jsii.Jsii.Proxy(ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether or not the advanced datapath metrics are enabled.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/container_cluster#enable_metrics ContainerCluster#enable_metrics}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getEnableMetrics();

    /**
     * Mode used to make Relay available.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/container_cluster#relay_mode ContainerCluster#relay_mode}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getRelayMode() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig> {
        java.lang.Object enableMetrics;
        java.lang.String relayMode;

        /**
         * Sets the value of {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig#getEnableMetrics}
         * @param enableMetrics Whether or not the advanced datapath metrics are enabled. This parameter is required.
         *                      Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/container_cluster#enable_metrics ContainerCluster#enable_metrics}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder enableMetrics(java.lang.Boolean enableMetrics) {
            this.enableMetrics = enableMetrics;
            return this;
        }

        /**
         * Sets the value of {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig#getEnableMetrics}
         * @param enableMetrics Whether or not the advanced datapath metrics are enabled. This parameter is required.
         *                      Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/container_cluster#enable_metrics ContainerCluster#enable_metrics}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder enableMetrics(com.hashicorp.cdktf.IResolvable enableMetrics) {
            this.enableMetrics = enableMetrics;
            return this;
        }

        /**
         * Sets the value of {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig#getRelayMode}
         * @param relayMode Mode used to make Relay available.
         *                  Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/container_cluster#relay_mode ContainerCluster#relay_mode}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder relayMode(java.lang.String relayMode) {
            this.relayMode = relayMode;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig {
        private final java.lang.Object enableMetrics;
        private final java.lang.String relayMode;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.enableMetrics = software.amazon.jsii.Kernel.get(this, "enableMetrics", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.relayMode = software.amazon.jsii.Kernel.get(this, "relayMode", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.enableMetrics = java.util.Objects.requireNonNull(builder.enableMetrics, "enableMetrics is required");
            this.relayMode = builder.relayMode;
        }

        @Override
        public final java.lang.Object getEnableMetrics() {
            return this.enableMetrics;
        }

        @Override
        public final java.lang.String getRelayMode() {
            return this.relayMode;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("enableMetrics", om.valueToTree(this.getEnableMetrics()));
            if (this.getRelayMode() != null) {
                data.set("relayMode", om.valueToTree(this.getRelayMode()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.containerCluster.ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig.Jsii$Proxy that = (ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig.Jsii$Proxy) o;

            if (!enableMetrics.equals(that.enableMetrics)) return false;
            return this.relayMode != null ? this.relayMode.equals(that.relayMode) : that.relayMode == null;
        }

        @Override
        public final int hashCode() {
            int result = this.enableMetrics.hashCode();
            result = 31 * result + (this.relayMode != null ? this.relayMode.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/container_cluster/ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig.java <==
package com.hashicorp.cdktf.providers.google.container_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:14.188Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.containerCluster.ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig")
@software.amazon.jsii.Jsii.Proxy(ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether or not the advanced datapath metrics are enabled.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#enable_metrics ContainerCluster#enable_metrics}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getEnableMetrics();

    /**
     * Whether or not Relay is enabled.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#enable_relay ContainerCluster#enable_relay}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getEnableRelay() {
        return null;
    }

    /**
     * Mode used to make Relay available.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#relay_mode ContainerCluster#relay_mode}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getRelayMode() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig> {
        java.lang.Object enableMetrics;
        java.lang.Object enableRelay;
        java.lang.String relayMode;

        /**
         * Sets the value of {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig#getEnableMetrics}
         * @param enableMetrics Whether or not the advanced datapath metrics are enabled. This parameter is required.
         *                      Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#enable_metrics ContainerCluster#enable_metrics}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder enableMetrics(java.lang.Boolean enableMetrics) {
            this.enableMetrics = enableMetrics;
            return this;
        }

        /**
         * Sets the value of {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig#getEnableMetrics}
         * @param enableMetrics Whether or not the advanced datapath metrics are enabled. This parameter is required.
         *                      Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#enable_metrics ContainerCluster#enable_metrics}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder enableMetrics(com.hashicorp.cdktf.IResolvable enableMetrics) {
            this.enableMetrics = enableMetrics;
            return this;
        }

        /**
         * Sets the value of {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig#getEnableRelay}
         * @param enableRelay Whether or not Relay is enabled.
         *                    Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#enable_relay ContainerCluster#enable_relay}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder enableRelay(java.lang.Boolean enableRelay) {
            this.enableRelay = enableRelay;
            return this;
        }

        /**
         * Sets the value of {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig#getEnableRelay}
         * @param enableRelay Whether or not Relay is enabled.
         *                    Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#enable_relay ContainerCluster#enable_relay}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder enableRelay(com.hashicorp.cdktf.IResolvable enableRelay) {
            this.enableRelay = enableRelay;
            return this;
        }

        /**
         * Sets the value of {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig#getRelayMode}
         * @param relayMode Mode used to make Relay available.
         *                  Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#relay_mode ContainerCluster#relay_mode}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder relayMode(java.lang.String relayMode) {
            this.relayMode = relayMode;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig {
        private final java.lang.Object enableMetrics;
        private final java.lang.Object enableRelay;
        private final java.lang.String relayMode;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.enableMetrics = software.amazon.jsii.Kernel.get(this, "enableMetrics", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.enableRelay = software.amazon.jsii.Kernel.get(this, "enableRelay", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.relayMode = software.amazon.jsii.Kernel.get(this, "relayMode", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.enableMetrics = java.util.Objects.requireNonNull(builder.enableMetrics, "enableMetrics is required");
            this.enableRelay = builder.enableRelay;
            this.relayMode = builder.relayMode;
        }

        @Override
        public final java.lang.Object getEnableMetrics() {
            return this.enableMetrics;
        }

        @Override
        public final java.lang.Object getEnableRelay() {
            return this.enableRelay;
        }

        @Override
        public final java.lang.String getRelayMode() {
            return this.relayMode;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("enableMetrics", om.valueToTree(this.getEnableMetrics()));
            if (this.getEnableRelay() != null) {
                data.set("enableRelay", om.valueToTree(this.getEnableRelay()));
            }
            if (this.getRelayMode() != null) {
                data.set("relayMode", om.valueToTree(this.getRelayMode()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.containerCluster.ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig.Jsii$Proxy that = (ContainerClusterMonitoringConfigAdvancedDatapathObservabilityConfig.Jsii$Proxy) o;

            if (!enableMetrics.equals(that.enableMetrics)) return false;
            if (this.enableRelay != null ? !this.enableRelay.equals(that.enableRelay) : that.enableRelay != null) return false;
            return this.relayMode != null ? this.relayMode.equals(that.relayMode) : that.relayMode == null;
        }

        @Override
        public final int hashCode() {
            int result = this.enableMetrics.hashCode();
            result = 31 * result + (this.enableRelay != null ? this.enableRelay.hashCode() : 0);
            result = 31 * result + (this.relayMode != null ? this.relayMode.hashCode() : 0);
            return result;
        }
    }
}
